@@ -12,6 +12,20 @@ from vcr.request import Request
 
 
 class MockClientResponse(ClientResponse):
+    def __init__(self, method, url):
+        super().__init__(
+            method=method,
+            url=url,
+            writer=None,
+            continue100=None,
+            timer=None,
+            request_info=None,
+            auto_decompress=None,
+            traces=None,
+            loop=asyncio.get_event_loop(),
+            session=None,
+        )
+
     # TODO: get encoding from header
     @asyncio.coroutine
     def json(self, *, encoding='utf-8', loads=json.loads):  # NOQA: E999
@@ -21,6 +35,10 @@ class MockClientResponse(ClientResponse):
     def text(self, encoding='utf-8'):
         return self.content.decode(encoding)
 
+    @asyncio.coroutine
+    def read(self):
+        return self.content
+
     @asyncio.coroutine
     def release(self):
         pass
@@ -71,7 +89,7 @@ def vcr_request(cassette, real_request):
                 'message': response.reason,
             },
             'headers': dict(response.headers),
-            'body': {'string': (yield from response.text())},  # NOQA: E999
+            'body': {'string': (yield from response.read())},  # NOQA: E999
             'url': response.url,
         }
         cassette.append(vcr_request, vcr_response)
